#delimit ;
set more 1;
log using /ddisk/illegal/newclass/create9416.log, replace;


*CREATING A NEW ILLEGAL IDENTIFIER BASED ON APPENDIX FROM HERITAGE REPORT;
*AND COMPARING IT TO THE CIS IDENTIFIER;

use /ddisk/illegal/ipums/cps9416.dta, replace;

gen immigrant=(citizen==2 | citizen==3);

generate gbtype=.;

*DEFINE THE NATIVE BORN;
replace gbtype=1 if immigrant==0;

*A PERSON IS LEGAL IF A CITIZEN;
replace gbtype=2 if immigrant==1 & citizen==2;

*A PERSON IS LEGAL IF ARRIVED BEFORE 1980;
replace gbtype=2 if immigrant==1 & yrimmig<1980;

*PERSON IS LEGAL IF RECEIVES SOCIAL SECURITY, SSI, MEDICAID, MEDICARE, OR MILITARY INSURANCE;
replace gbtype=2 if immigrant==1 & incss>0 & incss<99999;
replace gbtype=2 if immigrant==1 & incssi>0 & incssi<99999;
replace gbtype=2 if immigrant==1 & himcaid==2;
replace gbtype=2 if immigrant==1 & himcare==2;
replace gbtype=2 if immigrant==1 & hichamp==2;

*PERSON IS LEGAL IF WORKS FOR ARMED FORCES, GOVERNMENT, OR IS VETERAN;
replace gbtype=2 if immigrant==1 & classwkr>=25 & classwkr<=28;
replace gbtype=2 if immigrant==1 & vetstat==2;

*HOUSEHOLDER LIVING IN PUBLIC HOUSING OR RECEIVING SUBSIDIZED RENTS IS LEGAL;
replace gbtype=2 if immigrant==1 & relate==101 & pubhous==2;
replace gbtype=2 if immigrant==1 & relate==101 & rentsub==2;

*SPOUSES AND CHILDREN OF HOUSEHOLDER LIVING IN PUBLIC HOUSING OR RECEIVING SUBSIDIZED RENTS ARE LEGAL;
replace gbtype=2 if immigrant==1 & pubhous==2 & (relate==201 | relate==301 | relate==901);
replace gbtype=2 if immigrant==1 & rentsub==2 & (relate==201 | relate==301 | relate==901);

*CUBANS ARE LEGAL;
replace gbtype=2 if immigrant==1 & bpl==25000;

*WORKERS IN LICENSED OCCUPATIONS ARE LEGAL;
rename occ1990 occ90;

replace gbtype=2 if immigrant==1 &
	((occ90==3 | occ90==4 )
	| (occ90==16 | occ90==19)
	| (occ90==23 | occ90==35 | occ90==36 | occ90==43)
	| (occ90>=84 & occ90<=89) | (occ90>=95 & occ90<=97)
	| (occ90>=155 & occ90<=163)
	| (occ90>=178 & occ90<=179) 
	| (occ90>=203 & occ90<=208) 
 	| (occ90==226 | occ90==227)
	| occ90==375
	| (occ90>=417 & occ90<=423) | occ90==489
	| occ90==905);


*replace gbtype=2 if immigrant==1 &
	((occ90==3 | occ90==4 | occ90==7)
	| (occ90==14 | occ90==15 | occ90==16 | occ90==19)
	| (occ90==23 | occ90==24 | occ90==35 | occ90==36 | occ90==43)
	| (occ90>=84 & occ90<=89) | (occ90>=95 & occ90<=97)
	| (occ90>=98 & occ90<=106) | (occ90>=155 & occ90<=164)
	| (occ90>=178 & occ90<=179) | (occ90>=203 & occ90<=208)
	| (occ90==226 | occ90==227) | (occ90==254)
	| (occ90>=354 & occ90<=355) | occ90==375
	| (occ90>=417 & occ90<=423) | (occ90>=457 & occ90<=458) | occ90==489
	| (occ90==567 | occ90==575 | occ90==585)
	| (occ90>=804 & occ90<=809) | (occ90>=823 & occ90<=834)
	| occ90==905);


*replace gbtype=2 if immigrant==1 &
	((occ90==3 | occ90==4 | occ90==16 | occ90==19)
	| (occ90>=84 & occ90<=89) | (occ90>=95 & occ90<=97)
	| (occ90>=98 & occ90<=105) | (occ90>=155 & occ90<=163)
	| (occ90>=178 & occ90<=179) | (occ90>=203 & occ90<=208)
	| (occ90==226) | (occ90>=354 & occ90<=355)
	| (occ90>=415 & occ90<=423) | (occ90>=457 & occ90<=458)
	| (occ90>=804 & occ90<=809) | (occ90>=823 & occ90<=834)
	| occ90==905);

*replace gbtype=2 if immigrant==1 &
	((occ90==3 | occ90==4 | occ90==14 | occ90==15 | occ90==16 | occ90==19)
	| (occ90>=84 & occ90<=89) | (occ90>=95 & occ90<=97)
	| (occ90>=98 & occ90<=105) | (occ90>=113 & occ90<=163)
	| (occ90>=178 & occ90<=179) | (occ90>=203 & occ90<=208)
	| (occ90>=226 & occ90<=227) | (occ90>=354 & occ90<=355)
	| (occ90>=415 & occ90<=427) | (occ90>=457 & occ90<=458)
	| (occ90>=803 & occ90<=809) | (occ90>=823 & occ90<=834)
	| occ90==905);
	

*CREATES VARIABLE FINE, INDICATING PERSON IS EITHER LEGAL OR NATIVE-BORN;
generate fine=(imm==0 | gbtype==2);

*HEADHOLDER SPOUSE OF LEGAL "SPOUSE" IS LEGAL, AS LONG AS MARRIED SPOUSE PRESENT;
generate good=.;
replace good=1 if relate==201 & immigrant==1;
egen slegal=mean(good*fine), by(year serial);
tabulate slegal;
replace gbtype=2 if slegal>0 & immigrant==1 & (relate==101 & marst==1);

*SPOUSES, CHILDREN, GRANDCHILDREN OF LEGAL HOUSEHOLDERS ARE LEGAL;
*AS LONG AS SPOUSE IS MARRIED SPOUSE PRESENT;
drop good;
generate good=.;
replace good=1 if relate==101 & immigrant==1;
egen hlegal=mean(good*fine), by(year serial);
tabulate hlegal;
replace gbtype=2 if hlegal>0 & immigrant==1 & ((relate==201 & marst==1) | relate==301 | relate==901);

*THE RESIDUAL IMMIGRANTS ARE ILLEGAL;
replace gbtype=3 if gbtype==.;

generate illegal=(gbtype==1);
tabulate year [aw=wtsupp], sum(illegal);
tabulate year if imm==1 [aw=wtsupp], sum(illegal);

generate wtsupp2=int(wtsupp);
tabulate year gbtype [fw=wtsupp2];

keep year serial pernum gbtype;
sort year serial pernum;
save /ddisk/illegal/newclass/gbtype9416.dta, replace;

log close;

