#delimit ;
set more 1;
set matsize 4000;
log using /volumes/ddisk/illegal/revision/pregls.log, replace;


*USING POOLED 2012 AND 2013 CPS FROM PEW;
*ESTIMATING LABOR SUPPLY ELASTICITIES IN PEW DATA;


*MEN;
use /volumes/ddisk/illegal/pew/pooledcps2012.dta, replace;
append using /volumes/ddisk/illegal/pew/pooledcps2013.dta;

generate imm=(citizen==2 | citizen==3);
generate illegal=(Citstat==7);

drop if pew_age==.;

tabulate illegal [aw=ui_wgta];

tabulate citizen illegal;
tabulate imm illegal;
replace imm=1 if imm==0 & illegal==1;

keep if age>=20 & age<=64;
drop if schlcoll>=1 & schlcoll<=4;

generate lannual=log(incwage);
generate lweekly=log(incwage/wkswork1);
generate lwage=log(incwage/(wkswork1*uhrswork));
*drop if lannual==. | lweekly==. | lwage==.;

generate lfp=(labforce==2);
generate hours=wkswork1*uhrswork;
generate work1=(empstat==1 | empstat==10 | empstat==12);
generate work2=(hours>0);
generate lhours=log(wkswork1*uhrswork);


generate agecode=1*(age>=20 & age<=24) + 2*(age>=25 & age<=29)
	+ 3*(age>=30 & age<=34) + 4*(age>=35 & age<=39)
	+ 5*(age>=40 & age<=44) + 6*(age>=45 & age<=49)
	+ 7*(age>=50 & age<=54) + 8*(age>=55 & age<=59)
	+ 9*(age>=60 & age<=64);
generate edcode=1*(educ<=72) + 2*(educ==73) + 3*(educ>=81 & educ<=93) + 4*(educ>93);
tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);

tabulate agecode imm [aw=ui_wgta], sum(illegal) me noobs nofreq;
tabulate edcode imm [aw=ui_wgta], sum(illegal) me noobs nofreq;

tabulate edcode if imm==1 & illegal==0 [aw=ui_wgta];
tabulate edcode if imm==1 & illegal==1 [aw=ui_wgta];

generate age2=age*age;
generate age3=age2*age;
generate age4=age2*age2;

tabulate year, gen(dyear);

generate type=1*(imm==0) + 2*(imm==1 & illegal==0) + 3*(imm==1 & illegal==1);
generate legal=(imm==1 & illegal==0);

keep if sex==1;
tabulate yrimmig if imm==1 [aw=ui_wgta];

generate cpi =229.594 if year==2012;	
replace cpi =232.957 if year==2013;	
generate deflator=229.594/cpi;

replace lwage = lwage - log(deflator);


egen numer=sum(lwage*ui_wgta), by(year edcode agecode);
egen denom=sum(ui_wgta), by(year edcode agecode);
generate mlwage=numer/denom;

generate count=1;

collapse (mean) lfp work1 work2 hours lhours lwage mlwage (rawsum) weight=ui_wgta weight2=count
	[aw=ui_wgta], 
	by(edcode agecode type);
	
generate lhours2=log(hours);
generate skill=edcode*10 + agecode;

tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);
tabulate skill, gen(dskill);

generate mlwage1=mlwage*(type==1);
generate mlwage2=mlwage*(type==2);
generate mlwage3=mlwage*(type==3);
generate legal=(type==2);
generate illegal=(type==3);


generate qskill=skill*10 + type;
quietly tabulate qskill, gen(dqskill);

xi: regress lfp mlwage1-mlwage3 i.type i.edcode i.agecode 
	[aw=weight2], cluster(skill);
xi: regress work1 mlwage1-mlwage3 i.type i.edcode i.agecode 
	[aw=weight2], cluster(skill);
xi: regress work2 mlwage1-mlwage3 i.type i.edcode i.agecode 
	[aw=weight2], cluster(skill);
xi: regress lhours mlwage1-mlwage3 i.type i.edcode i.agecode 
	[aw=weight2], cluster(skill);
xi: regress lhours2 mlwage1-mlwage3 i.type i.edcode i.agecode 
	[aw=weight2], cluster(skill);




*WOMEN;
use /volumes/ddisk/illegal/pew/pooledcps2012.dta, replace;
append using /volumes/ddisk/illegal/pew/pooledcps2013.dta;

generate imm=(citizen==2 | citizen==3);
generate illegal=(Citstat==7);

drop if pew_age==.;

tabulate illegal [aw=ui_wgta];

tabulate citizen illegal;
tabulate imm illegal;
replace imm=1 if imm==0 & illegal==1;

keep if age>=20 & age<=64;
drop if schlcoll>=1 & schlcoll<=4;

generate lannual=log(incwage);
generate lweekly=log(incwage/wkswork1);
generate lwage=log(incwage/(wkswork1*uhrswork));
*drop if lannual==. | lweekly==. | lwage==.;

generate lfp=(labforce==2);
generate hours=wkswork1*uhrswork;
generate work1=(empstat==1 | empstat==10 | empstat==12);
generate work2=(hours>0);
generate lhours=log(wkswork1*uhrswork);


generate agecode=1*(age>=20 & age<=24) + 2*(age>=25 & age<=29)
	+ 3*(age>=30 & age<=34) + 4*(age>=35 & age<=39)
	+ 5*(age>=40 & age<=44) + 6*(age>=45 & age<=49)
	+ 7*(age>=50 & age<=54) + 8*(age>=55 & age<=59)
	+ 9*(age>=60 & age<=64);
generate edcode=1*(educ<=72) + 2*(educ==73) + 3*(educ>=81 & educ<=93) + 4*(educ>93);
tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);

tabulate agecode imm [aw=ui_wgta], sum(illegal) me noobs nofreq;
tabulate edcode imm [aw=ui_wgta], sum(illegal) me noobs nofreq;

tabulate edcode if imm==1 & illegal==0 [aw=ui_wgta];
tabulate edcode if imm==1 & illegal==1 [aw=ui_wgta];

generate age2=age*age;
generate age3=age2*age;
generate age4=age2*age2;

tabulate year, gen(dyear);

generate type=1*(imm==0) + 2*(imm==1 & illegal==0) + 3*(imm==1 & illegal==1);
generate legal=(imm==1 & illegal==0);

keep if sex==2;
tabulate yrimmig if imm==1 [aw=ui_wgta];

generate cpi =229.594 if year==2012;	
replace cpi =232.957 if year==2013;	
generate deflator=229.594/cpi;

replace lwage = lwage - log(deflator);


egen numer=sum(lwage*ui_wgta), by(year edcode agecode);
egen denom=sum(ui_wgta), by(year edcode agecode);
generate mlwage=numer/denom;

generate count=1;

collapse (mean) lfp work1 work2 hours lhours lwage mlwage (rawsum) weight=ui_wgta weight2=count
	[aw=ui_wgta], 
	by(edcode agecode type);
	
generate lhours2=log(hours);
generate skill=edcode*10 + agecode;

tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);
tabulate skill, gen(dskill);

generate mlwage1=mlwage*(type==1);
generate mlwage2=mlwage*(type==2);
generate mlwage3=mlwage*(type==3);
generate legal=(type==2);
generate illegal=(type==3);


generate qskill=skill*10 + type;
quietly tabulate qskill, gen(dqskill);

xi: regress lfp mlwage1-mlwage3 i.type i.edcode i.agecode 
	[aw=weight2], cluster(skill);
xi: regress work1 mlwage1-mlwage3 i.type i.edcode i.agecode 
	[aw=weight2], cluster(skill);
xi: regress work2 mlwage1-mlwage3 i.type i.edcode i.agecode 
	[aw=weight2], cluster(skill);
xi: regress lhours mlwage1-mlwage3 i.type i.edcode i.agecode 
	[aw=weight2], cluster(skill);
xi: regress lhours2 mlwage1-mlwage3 i.type i.edcode i.agecode 
	[aw=weight2], cluster(skill);



**************************************************************:
*ADDS THE VARIABLES INCLUDING STATE FIXED EFFECTS;	


*MEN;
use /volumes/ddisk/illegal/pew/pooledcps2012.dta, replace;
append using /volumes/ddisk/illegal/pew/pooledcps2013.dta;

generate imm=(citizen==2 | citizen==3);
generate illegal=(Citstat==7);

drop if pew_age==.;

tabulate illegal [aw=ui_wgta];

tabulate citizen illegal;
tabulate imm illegal;
replace imm=1 if imm==0 & illegal==1;

keep if age>=20 & age<=64;
drop if schlcoll>=1 & schlcoll<=4;

generate lannual=log(incwage);
generate lweekly=log(incwage/wkswork1);
generate lwage=log(incwage/(wkswork1*uhrswork));
*drop if lannual==. | lweekly==. | lwage==.;

generate lfp=(labforce==2);
generate hours=wkswork1*uhrswork;
generate work1=(empstat==1 | empstat==10 | empstat==12);
generate work2=(hours>0);
generate lhours=log(wkswork1*uhrswork);


generate agecode=1*(age>=20 & age<=24) + 2*(age>=25 & age<=29)
	+ 3*(age>=30 & age<=34) + 4*(age>=35 & age<=39)
	+ 5*(age>=40 & age<=44) + 6*(age>=45 & age<=49)
	+ 7*(age>=50 & age<=54) + 8*(age>=55 & age<=59)
	+ 9*(age>=60 & age<=64);
generate edcode=1*(educ<=72) + 2*(educ==73) + 3*(educ>=81 & educ<=93) + 4*(educ>93);
tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);

tabulate agecode imm [aw=wtsupp], sum(illegal) me noobs nofreq;
tabulate edcode imm [aw=wtsupp], sum(illegal) me noobs nofreq;

tabulate edcode if imm==1 & illegal==0 [aw=wtsupp];
tabulate edcode if imm==1 & illegal==1 [aw=wtsupp];

generate age2=age*age;
generate age3=age2*age;
generate age4=age2*age2;

tabulate year, gen(dyear);

generate type=1*(imm==0) + 2*(imm==1 & illegal==0) + 3*(imm==1 & illegal==1);
generate legal=(imm==1 & illegal==0);

keep if sex==1;
tabulate yrimmig if imm==1 [aw=wtsupp];

generate cpi =229.594 if year==2012;	
replace cpi =232.957 if year==2013;	
generate deflator=229.594/cpi;

replace lwage = lwage - log(deflator);

egen numer=sum(lwage*wtsupp), by(year edcode agecode);
egen denom=sum(wtsupp), by(year edcode agecode);
generate mlwage=numer/denom;
drop numer denom;

egen numer=sum(lwage*wtsupp), by(year state edcode agecode);
egen denom=sum(wtsupp), by(year state edcode agecode);
generate slwage=numer/denom;

generate count=1;

collapse (mean) lfp work1 work2 hours lhours lwage mlwage slwage (rawsum)
	 weight=wtsupp weight2=count [aw=wtsupp], 
	by(edcode agecode state type);

generate lhours2=log(hours);
generate skill=edcode*10 + agecode;

tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);
tabulate skill, gen(dskill);

generate mlwage1=mlwage*(type==1);
generate mlwage2=mlwage*(type==2);
generate mlwage3=mlwage*(type==3);
generate legal=(type==2);
generate illegal=(type==3);

generate qskill=skill*10 + type;
quietly tabulate qskill, gen(dqskill);


generate slwage1=slwage*(type==1);
generate slwage2=slwage*(type==2);
generate slwage3=slwage*(type==3);


xi: regress lhours2 slwage1-slwage3 i.type i.edcode i.agecode
	i.state*i.edcode i.state*i.age
	[aw=weight2], cluster(skill);








*WOMEN;
use /volumes/ddisk/illegal/pew/pooledcps2012.dta, replace;
append using /volumes/ddisk/illegal/pew/pooledcps2013.dta;

generate imm=(citizen==2 | citizen==3);
generate illegal=(Citstat==7);

drop if pew_age==.;

tabulate illegal [aw=ui_wgta];

tabulate citizen illegal;
tabulate imm illegal;
replace imm=1 if imm==0 & illegal==1;

keep if age>=20 & age<=64;
drop if schlcoll>=1 & schlcoll<=4;

generate lannual=log(incwage);
generate lweekly=log(incwage/wkswork1);
generate lwage=log(incwage/(wkswork1*uhrswork));
*drop if lannual==. | lweekly==. | lwage==.;

generate lfp=(labforce==2);
generate hours=wkswork1*uhrswork;
generate work1=(empstat==1 | empstat==10 | empstat==12);
generate work2=(hours>0);
generate lhours=log(wkswork1*uhrswork);


generate agecode=1*(age>=20 & age<=24) + 2*(age>=25 & age<=29)
	+ 3*(age>=30 & age<=34) + 4*(age>=35 & age<=39)
	+ 5*(age>=40 & age<=44) + 6*(age>=45 & age<=49)
	+ 7*(age>=50 & age<=54) + 8*(age>=55 & age<=59)
	+ 9*(age>=60 & age<=64);
generate edcode=1*(educ<=72) + 2*(educ==73) + 3*(educ>=81 & educ<=93) + 4*(educ>93);
tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);

tabulate agecode imm [aw=wtsupp], sum(illegal) me noobs nofreq;
tabulate edcode imm [aw=wtsupp], sum(illegal) me noobs nofreq;

tabulate edcode if imm==1 & illegal==0 [aw=wtsupp];
tabulate edcode if imm==1 & illegal==1 [aw=wtsupp];

generate age2=age*age;
generate age3=age2*age;
generate age4=age2*age2;

tabulate year, gen(dyear);

generate type=1*(imm==0) + 2*(imm==1 & illegal==0) + 3*(imm==1 & illegal==1);
generate legal=(imm==1 & illegal==0);

keep if sex==2;
tabulate yrimmig if imm==1 [aw=wtsupp];

generate cpi =229.594 if year==2012;	
replace cpi =232.957 if year==2013;	
generate deflator=229.594/cpi;

replace lwage = lwage - log(deflator);

egen numer=sum(lwage*wtsupp), by(year edcode agecode);
egen denom=sum(wtsupp), by(year edcode agecode);
generate mlwage=numer/denom;
drop numer denom;

egen numer=sum(lwage*wtsupp), by(year state edcode agecode);
egen denom=sum(wtsupp), by(year state edcode agecode);
generate slwage=numer/denom;

generate count=1;

collapse (mean) lfp work1 work2 hours lhours lwage mlwage slwage (rawsum)
	 weight=wtsupp weight2=count [aw=wtsupp], 
	by(edcode agecode state type);

generate lhours2=log(hours);
generate skill=edcode*10 + agecode;

tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);
tabulate skill, gen(dskill);

generate mlwage1=mlwage*(type==1);
generate mlwage2=mlwage*(type==2);
generate mlwage3=mlwage*(type==3);
generate legal=(type==2);
generate illegal=(type==3);

generate qskill=skill*10 + type;
quietly tabulate qskill, gen(dqskill);


generate slwage1=slwage*(type==1);
generate slwage2=slwage*(type==2);
generate slwage3=slwage*(type==3);


xi: regress lhours2 slwage1-slwage3 i.type i.edcode i.agecode
	i.state*i.edcode i.state*i.age
	[aw=weight2], cluster(skill);


log close;


