#delimit ;
set more 1;
set matsize 4000;
log using /volumes/ddisk/illegal/revision/pregwork.log, replace;


*USING POOLED 2012 AND 2013 CPS FROM PEW;

use /volumes/ddisk/illegal/pew/pooledcps2012.dta, clear;
append using /volumes/ddisk/illegal/pew/pooledcps2013.dta;

generate imm=(citizen==2 | citizen==3);
generate illegal=(Citstat==7);

drop if pew_age==.;

tabulate illegal [aw=ui_wgta];

tabulate citizen illegal;
tabulate imm illegal;
replace imm=1 if imm==0 & illegal==1;

keep if age>=20 & age<=64;

generate agecode=1*(age>=20 & age<=24) + 2*(age>=25 & age<=29)
	+ 3*(age>=30 & age<=34) + 4*(age>=35 & age<=39)
	+ 5*(age>=40 & age<=44) + 6*(age>=45 & age<=49)
	+ 7*(age>=50 & age<=54) + 8*(age>=55 & age<=59)
	+ 9*(age>=60 & age<=64);
generate agecode1=1*(age>=20 & age<=29)
	+ 2*(age>=30 & age<=39)
	+ 3*(age>=40 & age<=54) + 4*(age>=55 & age<=64);

generate edcode=1*(educ<=72) + 2*(educ==73) + 3*(educ>=81 & educ<=93) + 4*(educ>93);
tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);

tabulate agecode imm [aw=wtsupp], sum(illegal) me noobs nofreq;
tabulate edcode imm [aw=wtsupp], sum(illegal) me noobs nofreq;

tabulate edcode if imm==1 & illegal==0 [aw=wtsupp];
tabulate edcode if imm==1 & illegal==1 [aw=wtsupp];

generate age2=age*age;
generate age3=age2*age;
generate age4=age2*age2;

tabulate year, gen(dyear);

generate lfp=(labforce==2);
generate work=(empstat==1 | empstat==10 | empstat==12);
generate hours=wkswork1*uhrswork;
generate work2=(hours>0);
generate male=(sex==1);
generate workyear=(wkswork1>0);

generate urban=(metro>=2 & metro<=4);

generate type=1*(imm==0) + 2*(imm==1 & illegal==0) + 3*(imm==1 & illegal==1);
generate legal=(imm==1 & illegal==0);

tabulate educ99;
tabulate educ99, nol;

generate yeduc=2.5*(educ99==4) + 6.5*(educ99==5) + 9*(educ99==6) + 10*(educ99==7)
	+ 11*(educ99==8 | educ99==9) + 12*(educ99==10) + 14*(educ99>=11 & educ99<=14)
	+ 16*(educ99==15) + 17*(educ99==16) + 18*(educ99==17) + 20*(educ99==18);
tabulate educ99, sum(yeduc);

*DESCRIPTIVE STATISTICS;

tabulate type [aw=ui_wgta];
tabulate type [aw=ui_wgta], sum(male);

tabulate agecode1 type [aw=ui_wgta], co nofreq;
tabulate agecode1 type [aw=ui_wgta] if male==1, co nofreq;
tabulate agecode1 type [aw=ui_wgta] if male==0, co nofreq;

tabulate edcode type [aw=ui_wgta], co nofreq;
tabulate edcode type [aw=ui_wgta] if male==1, co nofreq;
tabulate edcode type [aw=ui_wgta] if male==0, co nofreq;

tabulate sex type [aw=ui_wgta], sum(age) me noobs nofreq;
tabulate sex type [aw=ui_wgta], sum(yeduc) me noobs nofreq;

tabulate sex type [aw=ui_wgta] , sum(lfp) me noobs nofreq;
tabulate sex type [aw=ui_wgta] , sum(work) me noobs nofreq;
tabulate sex type [aw=ui_wgta] , sum(work2) me noobs nofreq;
tabulate sex type [aw=ui_wgta] , sum(hours) me noobs nofreq;

generate year2=year-1;

generate cpi=.;
replace cpi =144.5 if year2==1993;	
replace cpi =148.2 if year2==1994;	
replace cpi =152.4 if year2==1995;	
replace cpi =156.9 if year2==1996;	
replace cpi =160.5 if year2==1997;	
replace cpi =163 if year2==1998;	
replace cpi =166.6 if year2==1999;	
replace cpi =172.2 if year2==2000;	
replace cpi =177.1 if year2==2001;	
replace cpi =179.9 if year2==2002;	
replace cpi =184 if year2==2003;	
replace cpi =188.9 if year2==2004;	
replace cpi =195.3 if year2==2005;	
replace cpi =201.6 if year2==2006;	
replace cpi =207.342 if year2==2007;	
replace cpi =215.303 if year2==2008;	
replace cpi =214.537 if year2==2009;	
replace cpi =218.056 if year2==2010;
replace cpi =224.939 if year2==2011;	
replace cpi =229.594 if year2==2012;	
replace cpi =232.957 if year2==2013;	
replace cpi =236.736 if year2==2014;	
replace cpi =237.017 if year2==2015;	
generate deflator=237.017/cpi;
replace incwage=incwage*deflator;
drop year;


generate lwage=log(incwage/(wkswork1*uhrswork));

tabulate sex type [aw=ui_wgta] , sum(lwage) me noobs nofreq;


tabulate state type [aw=wtsupp], co nofreq;
quietly tabulate state, gen(dstate);
tabulate type;

replace bpl=9900 if legal==0 & illegal==0;

*MAIN REGRESSIONS;


logit lfp male legal illegal if male==1 [pw=ui_wgta];
margins, dydx(legal illegal) ;
logit lfp male dage* legal illegal if male==1 [pw=ui_wgta];
margins, dydx(legal illegal) ;
logit lfp male dage* legal illegal if male==1 [pw=ui_wgta];
margins, dydx(legal illegal) ;
logit lfp deduc* male dage* legal illegal if male==1 [pw=ui_wgta];
margins, dydx(legal illegal) ;
logit lfp deduc* male dage* legal illegal dstate* metro if male==1 [pw=ui_wgta];
margins, dydx(legal illegal) ;



logit lfp male legal illegal if male==0 [pw=ui_wgta];
margins, dydx(legal illegal) ;
logit lfp male dage* legal illegal if male==0 [pw=ui_wgta];
margins, dydx(legal illegal) ;
logit lfp male dage* legal illegal if male==0 [pw=ui_wgta];
margins, dydx(legal illegal) ;
logit lfp deduc* male dage* legal illegal if male==0 [pw=ui_wgta];
margins, dydx(legal illegal) ;
logit lfp deduc* male dage* legal illegal dstate* metro if male==0 [pw=ui_wgta];
margins, dydx(legal illegal) ;



save /volumes/ddisk/data/junkillegal.dta, replace;

summ deduc* [aw=ui_wgta];
summ deduc* if illegal==1 [aw=ui_wgta];
summ deduc* if male==1 [aw=ui_wgta];
summ deduc* if male==1 & illegal==1 [aw=ui_wgta];

generate t2age=age*(type==2);
generate t3age=age*(type==3);
generate t2age2=age2*(type==2);
generate t3age2=age2*(type==3);
generate t2age3=age3*(type==2);
generate t3age3=age3*(type==3);
generate t2age4=age4*(type==2);
generate t3age4=age4*(type==3);


*AGE-EMPLOYMENT PROFILES;
*PREDICTION WITH EDUCATION EVALUATED AT MEANS OF ILLEGAL SAMPLE;

logit lfp legal illegal age age2-age4 t2age-t3age4 dyear* if male==1 
	[pw=ui_wgta];
predict lfpxb, xb;
generate whatm=exp(lfpxb)/(1 + exp(lfpxb)) if male==1;

drop lfpxb;

logit lfp legal illegal age age2-age4 t2age-t3age4 dyear* if male==0 
	[pw=ui_wgta];
predict lfpxb, xb;
generate whatf=exp(lfpxb)/(1 + exp(lfpxb)) if male==0;

drop lfpxb;

logit lfp legal illegal deduc1-deduc3 age age2-age4 t2age-t3age4 dyear* if male==1 
	[pw=ui_wgta];
predict lfpxb, xb;
replace lfpxb=lfpxb - deduc1*_b[deduc1] - deduc2*_b[deduc2] - deduc3*_b[deduc3];
replace lfpxb=lfpxb + .435*_b[deduc1] + .291*_b[deduc2] + .121*_b[deduc3];
generate ehatm=exp(lfpxb)/(1 + exp(lfpxb)) if male==1;

drop lfpxb;

logit lfp legal illegal deduc1-deduc3 age age2-age4 t2age-t3age4 dyear* if male==0 
	[pw=ui_wgta];
predict lfpxb, xb;
replace lfpxb=lfpxb - deduc1*_b[deduc1] - deduc2*_b[deduc2] - deduc3*_b[deduc3];
replace lfpxb=lfpxb + .435*_b[deduc1] + .291*_b[deduc2] + .121*_b[deduc3];
generate ehatf=exp(lfpxb)/(1 + exp(lfpxb)) if male==0;

generate weight=ui_wgta;

generate lfpm=lfp;
replace lfpm=. if male==0;
generate lfpf=lfp;
replace lfpf=. if male==1;

collapse (mean)  lfpm lfpf
	whatm whatf ehatm ehatf
	(rawsum) weight [aw=ui_wgta], by(type age);

reshape wide  lfpm lfpf whatm whatf ehatm ehatf
	weight, i(age) j(type);

generate legal=weight2/(weight1+weight2+weight3);
generate illegal=weight3/(weight1+weight2+weight3);
generate imm=(weight2+weight3)/(weight1+weight2+weight3);

list age legal illegal, separator(0) noobs;
list age whatm1 whatm2 whatm3, separator(0) noobs;
list age whatf1 whatf2 whatf3, separator(0) noobs;
list age ehatm1 ehatm2 ehatm3, separator(0) noobs;
list age ehatf1 ehatf2 ehatf3, separator(0) noobs;

log close;


