#delimit ;
set more 1;
set matsize 6000;
log using /volumes/ddisk/illegal/revision/regtrend2.log, replace;

*LOOKS AT PATTERN IN TREND COEFFICIENTS FOR MEN AND WOMEN;

*BY SKILL GROUP AND STATE;

*USES MY CODING OF ILLEGAL FOR ALL MARCH CPS FILES;


*MEN;

use /volumes/ddisk/illegal/ipums/cps9416.dta, replace;

sort year serial pernum;

merge year serial pernum using /volumes/ddisk/illegal/newclass/gbtype9416.dta;
drop _merge;

keep if year<=2014;

*SURVEY CHANGED AFTER 2014, SO 2014 WEIGHTS NEED TO BE RESCALED;
replace wtsupp=wtsupp/2 if year==2014;

tabulate year, gen(dyear);

generate imm=(citizen==2 | citizen==3);
generate illegal=(gbtype==3);

tabulate illegal [aw=wtsupp];
tabulate citizen illegal;
tabulate imm illegal;

replace imm=1 if imm==0 & illegal==1;

drop if schlcoll>=1 & schlcoll<=4;

generate lannual=log(incwage);
generate lweekly=log(incwage/wkswork1);
generate lwage=log(incwage/(wkswork1*uhrswork));
*drop if lannual==. | lweekly==. | lwage==.;

generate lfp=(labforce==2);

generate agecode=1*(age>=20 & age<=24) + 2*(age>=25 & age<=29)
         + 3*(age>=30 & age<=34) + 4*(age>=35 & age<=39)
         + 5*(age>=40 & age<=44) + 6*(age>=45 & age<=49)
         + 7*(age>=50 & age<=54) + 8*(age>=55 & age<=59)
         + 9*(age>=60 & age<=64);
generate edcode=1*(educ<=72) + 2*(educ==73) + 3*(educ>=81 & educ<=93) + 4*(educ>93);

tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);

generate age2=age*age;
generate age3=age2*age;
generate age4=age2*age2;

generate type=1*(imm==0) + 2*(imm==1 & illegal==0) + 3*(imm==1 & illegal==1);
generate legal=(imm==1 & illegal==0);

keep if sex==1;
tabulate yrimmig if imm==1 [aw=wtsupp];

egen numer=sum(lwage*wtsupp), by(year edcode agecode);
egen denom=sum(wtsupp), by(year edcode agecode);
generate mlwage=numer/denom;

rename statefip state;
sort year state;

generate skill=edcode*10 + agecode;
tabulate skill, gen(dskill);

generate lwage1=lwage*(type==1);
generate lwage2=lwage*(type==2);
generate lwage3=lwage*(type==3);
generate mlwage1=mlwage*(type==1);
generate mlwage2=mlwage*(type==2);
generate mlwage3=mlwage*(type==3);

generate tskill=state*100+skill;
quietly tabulate state, gen(dstate);

generate trend=year-1993;
generate ltrend=trend*legal;
generate itrend=trend*illegal;

generate qskill=year*1000 + skill;
generate qstate=year*1000 + state;

quietly tabulate qstate, gen(dqstate);

replace bpl=9900 if legal==0 & illegal==0;
quietly tabulate bpl, gen(dbpl);

regress lfp legal illegal trend ltrend itrend [aw=wtsupp],
	cluster(skill);
regress lfp legal illegal ltrend itrend dyear* [aw=wtsupp],
	cluster(skill);
regress lfp legal illegal ltrend itrend i.qskill [aw=wtsupp],
	cluster(skill);
areg lfp legal illegal ltrend itrend i.qskill [aw=wtsupp],
	absorb(qstate) cluster(skill);
areg lfp legal illegal ltrend itrend i.qskill dbpl* [aw=wtsupp],
	absorb(qstate) cluster(skill);



logit lfp legal illegal trend ltrend itrend [pw=wtsupp],
	cluster(skill);
margins, dydx(ltrend) at(legal==1);
margins, dydx(itrend) at(illegal==1);
logit lfp legal illegal ltrend itrend dyear* [pw=wtsupp],
	cluster(skill);
margins, dydx(ltrend) at(legal==1);
margins, dydx(itrend) at(illegal==1);
logit lfp legal illegal ltrend itrend i.qskill [pw=wtsupp],
	cluster(skill);
margins, dydx(ltrend) at(legal==1);
margins, dydx(itrend) at(illegal==1);
logit lfp legal illegal ltrend itrend i.qskill dqstate* [pw=wtsupp],
	cluster(skill);
margins, dydx(ltrend) at(legal==1);
margins, dydx(itrend) at(illegal==1);
logit lfp legal illegal ltrend itrend i.qskill dqstate* dbpl* [pw=wtsupp],
	cluster(skill);
margins, dydx(ltrend) ;
margins, dydx(itrend) ;


*******************************;

*WOMEN;

use /volumes/ddisk/illegal/ipums/cps9416.dta, replace;

sort year serial pernum;

merge year serial pernum using /volumes/ddisk/illegal/newclass/gbtype9416.dta;
drop _merge;

keep if year<=2014;

*SURVEY CHANGED AFTER 2014, SO 2014 WEIGHTS NEED TO BE RESCALED;
replace wtsupp=wtsupp/2 if year==2014;

tabulate year, gen(dyear);

generate imm=(citizen==2 | citizen==3);
generate illegal=(gbtype==3);

tabulate illegal [aw=wtsupp];
tabulate citizen illegal;
tabulate imm illegal;

replace imm=1 if imm==0 & illegal==1;

drop if schlcoll>=1 & schlcoll<=4;

generate lannual=log(incwage);
generate lweekly=log(incwage/wkswork1);
generate lwage=log(incwage/(wkswork1*uhrswork));
*drop if lannual==. | lweekly==. | lwage==.;

generate lfp=(labforce==2);

generate agecode=1*(age>=20 & age<=24) + 2*(age>=25 & age<=29)
         + 3*(age>=30 & age<=34) + 4*(age>=35 & age<=39)
         + 5*(age>=40 & age<=44) + 6*(age>=45 & age<=49)
         + 7*(age>=50 & age<=54) + 8*(age>=55 & age<=59)
         + 9*(age>=60 & age<=64);
generate edcode=1*(educ<=72) + 2*(educ==73) + 3*(educ>=81 & educ<=93) + 4*(educ>93);

tabulate agecode, gen(dage);
tabulate edcode, gen(deduc);

generate age2=age*age;
generate age3=age2*age;
generate age4=age2*age2;

generate type=1*(imm==0) + 2*(imm==1 & illegal==0) + 3*(imm==1 & illegal==1);
generate legal=(imm==1 & illegal==0);

keep if sex==2;
tabulate yrimmig if imm==1 [aw=wtsupp];

egen numer=sum(lwage*wtsupp), by(year edcode agecode);
egen denom=sum(wtsupp), by(year edcode agecode);
generate mlwage=numer/denom;

rename statefip state;
sort year state;

generate skill=edcode*10 + agecode;
tabulate skill, gen(dskill);

generate lwage1=lwage*(type==1);
generate lwage2=lwage*(type==2);
generate lwage3=lwage*(type==3);
generate mlwage1=mlwage*(type==1);
generate mlwage2=mlwage*(type==2);
generate mlwage3=mlwage*(type==3);

generate tskill=state*100+skill;
quietly tabulate state, gen(dstate);

generate trend=year-1993;
generate ltrend=trend*legal;
generate itrend=trend*illegal;

generate qskill=year*1000 + skill;
generate qstate=year*1000 + state;

quietly tabulate qstate, gen(dqstate);

replace bpl=9900 if legal==0 & illegal==0;
quietly tabulate bpl, gen(dbpl);

regress lfp legal illegal trend ltrend itrend [aw=wtsupp],
	cluster(skill);
regress lfp legal illegal ltrend itrend dyear* [aw=wtsupp],
	cluster(skill);
regress lfp legal illegal ltrend itrend i.qskill [aw=wtsupp],
	cluster(skill);
areg lfp legal illegal ltrend itrend i.qskill [aw=wtsupp],
	absorb(qstate) cluster(skill);
areg lfp legal illegal ltrend itrend i.qskill dbpl* [aw=wtsupp],
	absorb(qstate) cluster(skill);


logit lfp legal illegal trend ltrend itrend [pw=wtsupp],
	cluster(skill);
margins, dydx(ltrend) at(legal==1);
margins, dydx(itrend) at(illegal==1);
logit lfp legal illegal ltrend itrend dyear* [pw=wtsupp],
	cluster(skill);
margins, dydx(ltrend) at(legal==1);
margins, dydx(itrend) at(illegal==1);
logit lfp legal illegal ltrend itrend i.qskill [pw=wtsupp],
	cluster(skill);
margins, dydx(ltrend) at(legal==1);
margins, dydx(itrend) at(illegal==1);
logit lfp legal illegal ltrend itrend i.qskill dqstate* [pw=wtsupp],
	cluster(skill);
margins, dydx(ltrend) at(legal==1);
margins, dydx(itrend) at(illegal==1);
logit lfp legal illegal ltrend itrend i.qskill dqstate* dbpl* [pw=wtsupp],
	cluster(skill);
margins, dydx(ltrend) ;
margins, dydx(itrend) ;

	
log close;
